import { Component, ChangeDetectionStrategy, Input, HostBinding, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

var Defaults;
(function (Defaults) {
    Defaults["PrimaryColor"] = "#f3f3f3";
    Defaults["SecondaryColor"] = "#ecebeb";
    Defaults["PreserveAspectRatio"] = "xMidYMid meet";
    Defaults["Classes"] = "";
    Defaults["Speed"] = "1000ms";
    Defaults["Width"] = "400";
    Defaults["Height"] = "130";
    Defaults["Rx"] = "0";
    Defaults["Ry"] = "1";
})(Defaults || (Defaults = {}));

class NgxContentLoadingComponent {
    constructor() {
        this.width = Defaults.Width;
        this.height = Defaults.Height;
        this.primaryColor = Defaults.PrimaryColor;
        this.secondaryColor = Defaults.SecondaryColor;
        this.speed = Defaults.Speed;
        this.preserveAspectRatio = Defaults.PreserveAspectRatio;
    }
    get viewBox() {
        return `0 0 ${this.width} ${this.height}`;
    }
}
NgxContentLoadingComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-content-loading',
                template: "<ng-content select=\"[before-svg]\"></ng-content>\n\n<svg\n    [attr.preserveAspectRatio]=\"preserveAspectRatio\"\n    [attr.viewBox]=\"viewBox\">\n        <ng-content></ng-content>\n</svg>\n\n<ng-content select=\"[after-svg]\"></ng-content>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            },] }
];
NgxContentLoadingComponent.propDecorators = {
    width: [{ type: Input }],
    height: [{ type: Input }],
    primaryColor: [{ type: Input }],
    secondaryColor: [{ type: Input }],
    speed: [{ type: Input }],
    preserveAspectRatio: [{ type: Input }]
};

class SvgElementComponent {
    constructor(content) {
        this.content = content;
        this.clipPathId = getId();
        this.linearGradientId = getId();
    }
    get clipPathUrl() {
        return `url(#${this.clipPathId})`;
    }
    get linearGradientUrl() {
        return `url(#${this.linearGradientId})`;
    }
}
SvgElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-svg-element',
                template: "",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            },] }
];
SvgElementComponent.ctorParameters = () => [
    { type: NgxContentLoadingComponent }
];
function getId() {
    const id = performance.now() * Math.random();
    return id.toString();
}

class RectComponent extends SvgElementComponent {
    constructor(content) {
        super(content);
        this.content = content;
        this.rx = Defaults.Rx;
        this.ry = Defaults.Ry;
    }
}
RectComponent.decorators = [
    { type: Component, args: [{
                selector: '[ngx-rect]',
                template: "<svg:rect\n        [attr.x]=\"x\"\n        [attr.y]=\"y\"\n        [attr.rx]=\"rx\"\n        [attr.ry]=\"ry\"\n        [attr.width]=\"width\"\n        [attr.fill]=\"linearGradientUrl\"\n        [attr.clipPath]=\"clipPathUrl\"\n        [attr.height]=\"height\">\n</svg:rect>\n\n<svg:defs>\n    <svg:clipPath [attr.id]=\"clipPathId\"></svg:clipPath>\n\n    <svg:linearGradient [attr.id]=\"linearGradientId\">\n        <svg:stop ngx-svg-stop\n            [offset]=\"'0%'\"\n            [values]=\"'-2; 1'\"\n            [speed]=\"content.speed\"\n            [color]=\"content.primaryColor\">\n        </svg:stop>\n\n        <svg:stop ngx-svg-stop\n            [offset]=\"'50%'\"\n            [values]=\"'-1.5; 1.5'\"\n            [speed]=\"content.speed\"\n            [color]=\"content.secondaryColor\">\n        </svg:stop>\n\n        <svg:stop ngx-svg-stop\n            [offset]=\"'100%'\"\n            [values]=\"'-1; 2'\"\n            [speed]=\"content.speed\"\n            [color]=\"content.primaryColor\">\n        </svg:stop>\n    </svg:linearGradient>\n</svg:defs>\n",
                styles: [""]
            },] }
];
RectComponent.ctorParameters = () => [
    { type: NgxContentLoadingComponent }
];
RectComponent.propDecorators = {
    y: [{ type: Input }],
    x: [{ type: Input }],
    rx: [{ type: Input }],
    ry: [{ type: Input }],
    width: [{ type: Input }],
    height: [{ type: Input }],
    primaryColor: [{ type: Input }],
    secondaryColor: [{ type: Input }],
    speed: [{ type: Input }]
};

class SvgStopComponent {
}
SvgStopComponent.decorators = [
    { type: Component, args: [{
                selector: '[ngx-svg-stop]',
                template: "<svg:animate\n    attributeName=\"offset\"\n    [attr.values]=\"values\"\n    [attr.dur]=\"speed\"\n    [attr.opacity]=\"opacity\"\n    repeatCount=\"indefinite\"\n/>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            },] }
];
SvgStopComponent.propDecorators = {
    speed: [{ type: Input }],
    values: [{ type: Input }],
    opacity: [{ type: Input }],
    offset: [{ type: HostBinding, args: ['attr.offset',] }, { type: Input }],
    color: [{ type: HostBinding, args: ['attr.stop-color',] }, { type: Input }]
};

class FacebookPresetComponent {
}
FacebookPresetComponent.decorators = [
    { type: Component, args: [{
                selector: '[ngx-facebook-preset]',
                template: "<svg:g ngx-circle cx=\"25\" cy=\"25\" r=\"25\"></svg:g>\n<svg:g ngx-rect width=\"100\" height=\"5\" y=\"15\" x=\"60\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"60\" height=\"5\" y=\"30\" x=\"60\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"170\" height=\"5\" y=\"65\" x=\"0\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"220\" height=\"5\" y=\"80\" x=\"0\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"130\" height=\"5\" y=\"95\" x=\"0\" rx=\"5\" ry=\"5\"></svg:g>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            },] }
];

class InstagramPresetComponent {
}
InstagramPresetComponent.decorators = [
    { type: Component, args: [{
                selector: '[ngx-instagram-preset]',
                template: "<svg:g ngx-circle cx=\"25\" cy=\"25\" r=\"25\"></svg:g>\n<svg:g ngx-rect width=\"120\" height=\"10\" y=\"10\" x=\"60\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"40\" height=\"5\" y=\"30\" x=\"60\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"250\" height=\"250\" y=\"60\" x=\"0\" rx=\"5\" ry=\"5\"></svg:g>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            },] }
];

class CircleComponent extends SvgElementComponent {
    constructor(content) {
        super(content);
        this.content = content;
    }
}
CircleComponent.decorators = [
    { type: Component, args: [{
                selector: '[ngx-circle]',
                template: "<svg:circle\n        [attr.cx]=\"cx\"\n        [attr.cy]=\"cy\"\n        [attr.r]=\"r\"\n        [attr.fill]=\"linearGradientUrl\"\n        [attr.clipPath]=\"clipPathUrl\">\n</svg:circle>\n\n<svg:defs>\n    <svg:clipPath [attr.id]=\"clipPathId\"></svg:clipPath>\n\n    <svg:linearGradient [attr.id]=\"linearGradientId\">\n        <svg:stop ngx-svg-stop\n            [offset]=\"'0%'\"\n            [values]=\"'-2; 1'\"\n            [speed]=\"content.speed\"\n            [color]=\"content.primaryColor\">\n        </svg:stop>\n\n        <svg:stop ngx-svg-stop\n            [offset]=\"'50%'\"\n            [values]=\"'-1.5; 1.5'\"\n            [speed]=\"content.speed\"\n            [color]=\"content.secondaryColor\">\n        </svg:stop>\n\n        <svg:stop ngx-svg-stop\n            [offset]=\"'100%'\"\n            [values]=\"'-1; 2'\"\n            [speed]=\"content.speed\"\n            [color]=\"content.primaryColor\">\n        </svg:stop>\n    </svg:linearGradient>\n</svg:defs>\n",
                styles: [""]
            },] }
];
CircleComponent.ctorParameters = () => [
    { type: NgxContentLoadingComponent }
];
CircleComponent.propDecorators = {
    r: [{ type: Input }],
    cx: [{ type: Input }],
    cy: [{ type: Input }]
};

class CodePresetComponent {
    constructor() { }
    ngOnInit() {
    }
}
CodePresetComponent.decorators = [
    { type: Component, args: [{
                selector: '[ngx-code-preset]',
                template: "<svg:g ngx-rect width=\"60\" height=\"10\" y=\"15\" x=\"0\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"90\" height=\"10\" y=\"15\" x=\"70\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"20\" height=\"10\" y=\"15\" x=\"170\" rx=\"5\" ry=\"5\"></svg:g>\n\n<svg:g ngx-rect width=\"100\" height=\"10\" y=\"35\" x=\"9\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"120\" height=\"10\" y=\"35\" x=\"120\" rx=\"5\" ry=\"5\"></svg:g>\n\n<svg:g ngx-rect width=\"90\" height=\"10\" y=\"55\" x=\"5\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"90\" height=\"10\" y=\"55\" x=\"105\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"70\" height=\"10\" y=\"55\" x=\"205\" rx=\"5\" ry=\"5\"></svg:g>\n\n<svg:g ngx-rect width=\"30\" height=\"10\" y=\"75\" x=\"0\" rx=\"5\" ry=\"5\"></svg:g>\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
CodePresetComponent.ctorParameters = () => [];

class BulletListPresetComponent {
}
BulletListPresetComponent.decorators = [
    { type: Component, args: [{
                selector: '[ngx-bullet-list-preset]',
                template: "<svg:g ngx-circle cx=\"7\" cy=\"7\" r=\"7\"></svg:g>\n<svg:g ngx-circle cx=\"7\" cy=\"37\" r=\"7\"></svg:g>\n<svg:g ngx-circle cx=\"7\" cy=\"67\" r=\"7\"></svg:g>\n<svg:g ngx-circle cx=\"7\" cy=\"97\" r=\"7\"></svg:g>\n\n<svg:g ngx-rect width=\"200\" height=\"12\" y=\"2\" x=\"20\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"200\" height=\"12\" y=\"32\" x=\"20\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"200\" height=\"12\" y=\"62\" x=\"20\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"200\" height=\"12\" y=\"92\" x=\"20\" rx=\"5\" ry=\"5\"></svg:g>\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];

class ListPresetComponent {
    constructor() { }
    ngOnInit() {
    }
}
ListPresetComponent.decorators = [
    { type: Component, args: [{
                selector: '[ngx-list-preset]',
                template: "<svg:g ngx-rect width=\"200\" height=\"10\" y=\"0\" x=\"0\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"180\" height=\"10\" y=\"20\" x=\"20\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"160\" height=\"10\" y=\"40\" x=\"20\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"200\" height=\"10\" y=\"60\" x=\"0\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"180\" height=\"10\" y=\"80\" x=\"20\" rx=\"5\" ry=\"5\"></svg:g>\n<svg:g ngx-rect width=\"60\" height=\"10\" y=\"100\" x=\"20\" rx=\"5\" ry=\"5\"></svg:g>\n\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
ListPresetComponent.ctorParameters = () => [];

class NgxContentLoadingModule {
}
NgxContentLoadingModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    NgxContentLoadingComponent,
                    RectComponent,
                    CircleComponent,
                    SvgElementComponent,
                    SvgStopComponent,
                    FacebookPresetComponent,
                    InstagramPresetComponent,
                    CodePresetComponent,
                    BulletListPresetComponent,
                    ListPresetComponent
                ],
                exports: [
                    NgxContentLoadingComponent,
                    RectComponent,
                    CircleComponent,
                    FacebookPresetComponent,
                    InstagramPresetComponent,
                    CodePresetComponent,
                    BulletListPresetComponent,
                    ListPresetComponent
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NgxContentLoadingModule, NgxContentLoadingComponent as ɵa, RectComponent as ɵb, SvgElementComponent as ɵc, CircleComponent as ɵd, SvgStopComponent as ɵe, FacebookPresetComponent as ɵf, InstagramPresetComponent as ɵg, CodePresetComponent as ɵh, BulletListPresetComponent as ɵi, ListPresetComponent as ɵj };
//# sourceMappingURL=ngx-content-loading.js.map
